@@ -6,9 +6,9 @@ import sys
 from functools import partial
 
 from kraken.core import BuildError, Context, Task, TaskGraph
-from kraken.core.executor import COLORS_BY_RESULT
 from termcolor import colored
 
+from ..executor import get_executor_observer
 from .base import BuildGraphCommand
 
 
@@ -54,20 +54,10 @@ class RunCommand(BuildGraphCommand):
                     return 1
 
             try:
-                context.execute(graph, args.verbose > 0)
+                context.execute(graph, observer=get_executor_observer())
             except BuildError as exc:
                 print()
                 print(colored("Error: %s" % (exc,), "red"), file=sys.stderr, flush=True)
                 status_code = 1
 
-            print()
-            print(colored("Build summary", "blue", attrs=["underline", "bold"]))
-            print()
-            tasks1 = {task: graph.get_status(task) for task in graph.tasks()}
-            tasks = {task: status for task, status in tasks1.items() if status is not None}
-            longest_path = max(map(len, (t.path for t in tasks)))
-            for task, status in sorted(tasks.items(), key=lambda t: t[0].path):
-                print(task.path.ljust(longest_path), colored(status.type.name, COLORS_BY_RESULT[status.type]))
-            print()
-
         return status_code
